@@ -2,11 +2,14 @@
 # compat.rb -- cross platform compatibility
 #
 # Author: IPR -- Internet Programming with Ruby -- writers
-# Copyright (C) 2002 GOTOU Yuuzou
+# Copyright (c) 2002 GOTOU Yuuzou
+# Copyright (c) 2002 Internet Programming with Ruby writers. All rights
+# reserved.
 #
-# $IPR: compat.rb,v 1.1 2002/02/05 20:19:45 gotoyuzo Exp $
+# $IPR: compat.rb,v 1.5 2002/09/21 12:23:35 gotoyuzo Exp $
 
 module Errno
+  class EPROTO       < SystemCallError; end
   class ECONNRESET   < SystemCallError; end
   class ECONNABORTED < SystemCallError; end
 end
