@@ -2,42 +2,34 @@
 # httpservlet.rb -- HTTPServlet Module
 #
 # Author: IPR -- Internet Programming with Ruby -- writers
-# Copyright (C) 2000 TAKAHASHI Masayoshi, GOTOU Yuuzou
+# Copyright (c) 2000 TAKAHASHI Masayoshi, GOTOU Yuuzou
+# Copyright (c) 2002 Internet Programming with Ruby writers. All rights
+# reserved.
 #
-# $IPR: abstract.rb,v 1.12 2002/02/05 20:20:39 gotoyuzo Exp $
+# $IPR: abstract.rb,v 1.21 2002/09/21 12:23:41 gotoyuzo Exp $
 
 require 'thread'
 
 require 'webrick/htmlutils'
 require 'webrick/httputils'
 require 'webrick/httpstatus'
-require 'webrick/httpdate'
 
 module WEBrick
   module HTTPServlet
 
     class AbstractServlet
-      def self.require_path_info val
-        module_eval %-
-          def self.require_path_info?
-            #{val}
-          end
-        -
-      end
-      require_path_info true
-
       def self.get_instance(config, *options)
         self.new(config, *options)
       end
 
-      def initialize(config, *options)
-        @config = config
-        @logger = config[:Logger]
+      def initialize(server, *options)
+        @server = @config = server
+        @logger = @server[:Logger]
         @options = options
       end
 
       def service(req, res)
-        method_name = "do_" + req.request_method.gsub(/-/, "_")
+        method_name = "do_" + req.request_method
         if respond_to?(method_name)
           send(method_name, req, res)
         else
@@ -53,6 +45,25 @@ module WEBrick
       def do_HEAD(req, res)
         do_GET(req, res)
       end
+
+      def do_OPTIONS(req, res)
+        m = self.methods.grep(/^do_[A-Z]+$/)
+        m.collect!{|i| i.sub(/do_/, "") }
+        m.sort!
+        res["allow"] = m.join(",")
+      end
+
+      private
+
+      def redirect_to_directory_uri(req, res)
+        if req.path[-1] != ?/
+          location = req.path + "/"
+          if req.query_string && req.query_string.size > 0
+            location << "?" << req.query_string
+          end
+          res.set_redirect(HTTPStatus::MovedPermanently, location)
+        end
+      end
     end
 
   end
