@@ -1,4 +1,13 @@
-comspec = ENV['COMSPEC']      # for mswin32
+#
+# cgi_runner.rb -- CGI launcher.
+#
+# Author: IPR -- Internet Programming with Ruby -- writers
+# Copyright (c) 2000 TAKAHASHI Masayoshi, GOTOU YUUZOU
+# Copyright (c) 2002 Internet Programming with Ruby writers. All rights
+# reserved.
+#
+# $IPR: cgi_runner.rb,v 1.8 2002/09/21 12:23:41 gotoyuzo Exp $
+
 STDIN.binmode
 
 len = STDIN.sysread(8).to_i
@@ -17,9 +26,9 @@ hash.each{|k, v| ENV[k] = v if v }
 
 dir = File::dirname(ENV["SCRIPT_FILENAME"])
 Dir::chdir dir
-if comspec && /mingw|mswin/ =~ RUBY_PLATFORM
-  # I don't know the correct way to execute CGI scripts on win32.
-  system(comspec, "/c", ENV['SCRIPT_FILENAME'])
-  exit
+
+if interpreter = ARGV[0]
+  exec(interpreter, ENV["SCRIPT_FILENAME"])
+  # NOTREACHED
 end
 exec ENV["SCRIPT_FILENAME"]
