@@ -2,11 +2,14 @@
 # utils.rb -- Miscellaneous utilities
 #
 # Author: IPR -- Internet Programming with Ruby -- writers
-# Copyright (C) 2001 TAKAHASHI Masayoshi, GOTOU Yuuzou
+# Copyright (c) 2001 TAKAHASHI Masayoshi, GOTOU Yuuzou
+# Copyright (c) 2002 Internet Programming with Ruby writers. All rights
+# reserved.
 #
-# $IPR: utils.rb,v 1.2 2002/02/05 20:20:32 gotoyuzo Exp $
+# $IPR: utils.rb,v 1.7 2002/09/21 12:23:37 gotoyuzo Exp $
 
 require 'socket'
+require 'fcntl'
 begin
   require 'etc'
 rescue LoadError
@@ -15,6 +18,13 @@ end
 module WEBrick
   module Utils
 
+    def set_close_on_exec(io)
+      if defined?(Fcntl::FD_CLOEXEC)
+        io.fcntl(Fcntl::FD_CLOEXEC, 1)
+      end
+    end
+    module_function :set_close_on_exec
+
     def su(user, group=nil)
       if defined?(Etc)
         pw = Etc.getpwnam(user)
@@ -30,13 +40,10 @@ module WEBrick
     def getservername
       host = Socket::gethostname
       begin
-        ai = Socket::getaddrinfo(host, nil,
-               Socket::AF_UNSPEC, Socket::SOCK_STREAM)
-        ret = ai[0][2]
+        Socket::gethostbyname(host)[0]
       rescue
-        ret = host
+        host
       end
-      ret
     end
     module_function :getservername
 
