@@ -1,11 +1,11 @@
-#!/usr/local/bin/ruby
+#!/usr/bin/env ruby
 
 $:.unshift('../../lib')
 
 require 'webrick/https'
 require 'getopts'
 
-getopts nil, 'r:'
+getopts nil, 'r:', 'p:8808'
 
 dir = File::dirname(File::expand_path(__FILE__))
 
@@ -17,12 +17,12 @@ begin
   cert = OpenSSL::X509::Certificate.new(data)
 rescue
   $stderr.puts "Switching to use self-signed certificate"
-  cert_name = [ ["C","JP"], ["O","WEBrick.Org"], ["CN", "WWW"] ]
+  cert_name = [ ["C","JP"], ["O","Example.JP"], ["CN", "WWW"] ]
 end
 
 s=WEBrick::HTTPServer.new(
   :BindAddress      => "0.0.0.0",
-  :Port             => 2000,
+  :Port             => $OPT_p.to_i, 
   :Logger           => WEBrick::Log::new($stderr, WEBrick::Log::DEBUG),
   :DocumentRoot     => $OPT_r || dir + "/htdocs",
   :SSLEnable        => true,
