@@ -20,9 +20,7 @@ class TestWEBrickLog < RUNIT::TestCase
       str = f.read()
       col = str.split("\n")
       i=-1
-      assert_equal(" INFO  Logging start (level=5).",col[i+=1].sub(/\[.*\]/,''))
       assert_equal(" FATAL hogehoge", col[i+=1].sub(/\[.*\]/,''))
-      assert_equal(" INFO  Logging end.", col[i+=1].sub(/\[.*\]/,''))
     ensure
       f.close
     end
@@ -39,9 +37,7 @@ class TestWEBrickLog < RUNIT::TestCase
       f.rewind
       str = f.read()
       col = str.split("\n")
-      assert_equal(" INFO  Logging start (level=4).", col[0].sub(/\[.*\]/,''))
-      assert_equal(" FATAL test_fatal", col[1].sub(/\[.*\]/,''))
-      assert_equal(" INFO  Logging end.", col[2].sub(/\[.*\]/,''))
+      assert_equal(" FATAL test_fatal", col[0].sub(/\[.*\]/,''))
     ensure
       f.close
     end
